@@ -22,6 +22,8 @@ from numalogic.tests.registry._mlflow_utils import (
     return_pytorch_rundata_dict,
     return_empty_rundata,
     return_pytorch_rundata_list,
+    mock_list_of_model_version,
+    mock_list_of_model_version2,
 )
 
 TRACKING_URI = "http://0.0.0.0:5009"
@@ -50,9 +52,10 @@ class TestMLflow(unittest.TestCase):
     @patch("mlflow.log_param", mock_log_state_dict)
     @patch("mlflow.tracking.MlflowClient.transition_model_version_stage", mock_transition_stage)
     @patch("mlflow.tracking.MlflowClient.get_latest_versions", mock_get_model_version)
+    @patch("mlflow.tracking.MlflowClient.search_model_versions", mock_list_of_model_version)
     def test_insert_model(self):
         model = self.model
-        ml = MLflowRegistrar(TRACKING_URI, artifact_type="pytorch")
+        ml = MLflowRegistrar(TRACKING_URI, artifact_type="pytorch", models_to_retain=2)
         skeys = ["model_", "nnet"]
         dkeys = ["error1"]
 
@@ -61,7 +64,7 @@ class TestMLflow(unittest.TestCase):
             dkeys=dkeys,
             primary_artifact=model,
             secondary_artifacts=[make_pipeline(return_scaler)],
-            artifact_state_dict=model.state_dict(),
+            **model.state_dict(),
         )
         mock_status = "READY"
         self.assertEqual(mock_status, status.status)
@@ -69,6 +72,7 @@ class TestMLflow(unittest.TestCase):
     @patch("mlflow.sklearn.log_model", mock_log_model_sklearn)
     @patch("mlflow.tracking.MlflowClient.transition_model_version_stage", mock_transition_stage)
     @patch("mlflow.tracking.MlflowClient.get_latest_versions", mock_get_model_version)
+    @patch("mlflow.tracking.MlflowClient.search_model_versions", mock_list_of_model_version2)
     def test_insert_model_sklearn(self):
         model = self.model_sklearn
         ml = MLflowRegistrar(TRACKING_URI, artifact_type="sklearn")
@@ -104,7 +108,6 @@ class TestMLflow(unittest.TestCase):
         )
         data = ml.load(skeys=skeys, dkeys=dkeys)
         self.assertIsInstance(data["primary_artifact"], VanillaAE)
-        print(data["secondary_artifacts"])
         self.assertIsInstance(data["secondary_artifacts"]["preproc"], Pipeline)
         self.assertIsInstance(data["secondary_artifacts"]["postproc"], Pipeline)
 
@@ -130,12 +133,12 @@ class TestMLflow(unittest.TestCase):
         )
         data = ml.load(skeys=skeys, dkeys=dkeys)
         self.assertIsInstance(data["primary_artifact"], VanillaAE)
-        print(data["secondary_artifacts"])
         self.assertIsInstance(data["secondary_artifacts"], list)
 
     @patch("mlflow.sklearn.log_model", mock_log_model_sklearn)
     @patch("mlflow.tracking.MlflowClient.transition_model_version_stage", mock_transition_stage)
     @patch("mlflow.tracking.MlflowClient.get_latest_versions", mock_get_model_version)
+    @patch("mlflow.tracking.MlflowClient.search_model_versions", mock_list_of_model_version2)
     @patch("mlflow.sklearn.load_model", Mock(return_value=RandomForestRegressor()))
     @patch("mlflow.tracking.MlflowClient.get_run", Mock(return_value=return_empty_rundata()))
     def test_select_model_when_sklearn_model_exist(self):
@@ -172,10 +175,6 @@ class TestMLflow(unittest.TestCase):
         self.assertIsInstance(data["primary_artifact"], VanillaAE)
         self.assertEqual(data["metadata"], None)
 
-    @patch("mlflow.pyfunc.log_model", mock_log_model_pytorch)
-    @patch("mlflow.log_param", mock_log_state_dict)
-    @patch("mlflow.tracking.MlflowClient.transition_model_version_stage", mock_transition_stage)
-    @patch("mlflow.tracking.MlflowClient.get_latest_versions", mock_get_model_version)
     @patch("mlflow.pyfunc.load_model", Mock(side_effect=RuntimeError))
     def test_select_model_when_no_model_01(self):
         fake_skeys = ["Fakemodel_"]
@@ -185,10 +184,6 @@ class TestMLflow(unittest.TestCase):
             ml.load(skeys=fake_skeys, dkeys=fake_dkeys)
             self.assertTrue(log.output)
 
-    @patch("mlflow.tensorflow.log_model", mock_log_model_pytorch)
-    @patch("mlflow.log_param", mock_log_state_dict)
-    @patch("mlflow.tracking.MlflowClient.transition_model_version_stage", mock_transition_stage)
-    @patch("mlflow.tracking.MlflowClient.get_latest_versions", mock_get_model_version)
     @patch("mlflow.tensorflow.load_model", Mock(side_effect=RuntimeError))
     def test_select_model_when_no_model_02(self):
         fake_skeys = ["Fakemodel_"]
@@ -198,6 +193,19 @@ class TestMLflow(unittest.TestCase):
             ml.load(skeys=fake_skeys, dkeys=fake_dkeys)
             self.assertTrue(log.output)
 
+    @patch("mlflow.tracking.MlflowClient.get_latest_versions", mock_get_model_version)
+    @patch(
+        "mlflow.tracking.MlflowClient.transition_model_version_stage",
+        Mock(side_effect=RuntimeError),
+    )
+    def test_transition_stage_fail(self):
+        fake_skeys = ["Fakemodel_"]
+        fake_dkeys = ["error"]
+        ml = MLflowRegistrar(TRACKING_URI, artifact_type="tensorflow")
+        with self.assertLogs(level="ERROR") as log:
+            ml.transition_stage(fake_skeys, fake_dkeys)
+            self.assertTrue(log.output)
+
     def test_no_implementation(self):
         with self.assertRaises(NotImplementedError):
             MLflowRegistrar(TRACKING_URI, artifact_type="some_random")
@@ -206,6 +214,7 @@ class TestMLflow(unittest.TestCase):
     @patch("mlflow.log_param", mock_log_state_dict)
     @patch("mlflow.tracking.MlflowClient.transition_model_version_stage", mock_transition_stage)
     @patch("mlflow.tracking.MlflowClient.get_latest_versions", mock_get_model_version)
+    @patch("mlflow.tracking.MlflowClient.search_model_versions", mock_list_of_model_version2)
     @patch("mlflow.tracking.MlflowClient.delete_model_version", None)
     @patch("mlflow.pytorch.load_model", Mock(side_effect=RuntimeError))
     def test_delete_model_when_model_exist(self):
